==> monodevelop_0.9.orig.tar.gz: monodevelop-0.9/Core/src/MonoDevelop.Core.Gui/MonoDevelop.Core.Gui.Codons/LinkItemCodon.cs <==
//
// LinkItemCodon.cs
//
// Author:
//   Lluis Sanchez Gual
//

//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//


using System;
using System.Collections;
using MonoDevelop.Components.Commands;
using MonoDevelop.Core;
using MonoDevelop.Core.Gui;
using MonoDevelop.Core.AddIns;

namespace MonoDevelop.Core.Gui.Codons
{
	[CodonNameAttribute ("LinkItem")]
	internal class LinkItemCodon : AbstractCodon
	{
		[XmlMemberAttribute ("_label")]
		string label;
		
		[XmlMemberAttribute("link")]
		string link;
		
//		[XmlMemberAttribute("description")]
//		string description;
		
		public override object BuildItem (object owner, ArrayList subItems, ConditionCollection conditions)
		{
			return new LinkCommandEntry (label, link, ResourceService.GetStockId ("md-web-search-icon"));
		}
	}
}

==> monodevelop_0.14+dfsg.orig.tar.gz: monodevelop-0.14/Core/src/MonoDevelop.Core.Gui/MonoDevelop.Core.Gui.Codons/LinkItemCodon.cs <==
//
// LinkItemCodon.cs
//
// Author:
//   Lluis Sanchez Gual
//

//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//


using System;
using System.Collections;
using System.ComponentModel;
using MonoDevelop.Components.Commands;
using MonoDevelop.Core;
using MonoDevelop.Core.Gui;
using Mono.Addins;

namespace MonoDevelop.Core.Gui.Codons
{
	[ExtensionNode (Description="A menu or toolbar item that opens an URL when activated")]
	internal class LinkItemCodon : InstanceExtensionNode
	{
		[NodeAttribute ("_label", "Label of the item.")]
		string label;
		
		[NodeAttribute ("link", "URL to open.")]
		string link;
		
//		[XmlMemberAttribute("description")]
//		string description;
		
		public override object CreateInstance ()
		{
			return new LinkCommandEntry (label, link, ResourceService.GetStockId ("md-web-search-icon"));
		}
	}
}
